@@ -33,8 +33,6 @@ typedef struct {
     Options *options;
 } CappletData;
 
-const char *capplet_get_ui_filename(void);
-
 /* This is set when one of the widgets is being changed by the program, so we
  * should ignore the resultant signal */
 extern gboolean capplet_ignore_changes;
@@ -77,13 +75,13 @@ void on_combo_changed(GtkComboBox * combo, CappletData *);
 
 /**********************************************/
 
-/* As cappelt_set_boolean_toggle but sets the given state instead of
+/* As capplet_set_boolean_toggle but sets the given state instead of
  * looking up option */
 void capplet_set_toggle(CappletData *capp, const char *name, gboolean state);
 
 /* Convenience functions to lookup an option and set the widget with the same
- * name */
-void capplet_set_boolean_toggle(CappletData *capp,
+ * name. Returns the option's value */
+gboolean capplet_set_boolean_toggle(CappletData *capp,
     const char *name, gboolean dflt);
 
 void capplet_set_text_entry(CappletData *capp,
