@@ -41,37 +41,17 @@ multitab_close_button_style_updated (GtkWidget *self)
 static void
 multitab_close_button_class_init(MultitabCloseButtonClass *klass)
 {
-    static const char *button_style =
-            "* {\n"
-              "-GtkButton-default-border : 0;\n"
-              "-GtkButton-default-outside-border : 0;\n"
-              "-GtkButton-inner-border: 0;\n"
-              "-GtkWidget-focus-line-width : 0;\n"
-              "-GtkWidget-focus-padding : 0;\n"
-              "padding: 0;\n"
-            "}";
+    GtkWidgetClass *wk = GTK_WIDGET_CLASS (klass);
 
-    klass->style_provider = gtk_css_provider_new ();
-    gtk_css_provider_load_from_data (klass->style_provider,
-            button_style, -1, NULL);
-    GTK_WIDGET_CLASS (klass)->style_updated =
-            multitab_close_button_style_updated;
+    wk->style_updated = multitab_close_button_style_updated;
+    gtk_widget_class_set_css_name (wk, "multitab-close-button");
 }
 
 static void
 multitab_close_button_init(MultitabCloseButton *self)
 {
-    GtkButton *parent = GTK_BUTTON(self);
     GtkWidget *image = gtk_image_new ();
-    GtkWidget *w = GTK_WIDGET(self);
 
-    gtk_button_set_relief(parent, GTK_RELIEF_NONE);
-    gtk_button_set_focus_on_click(parent, FALSE);
-    gtk_style_context_add_provider (gtk_widget_get_style_context (w),
-            GTK_STYLE_PROVIDER (MULTITAB_CLOSE_BUTTON_GET_CLASS
-                    (self)->style_provider),
-            GTK_STYLE_PROVIDER_PRIORITY_APPLICATION);
-    gtk_widget_set_name (w, "multitab-close-button");
     self->image = GTK_IMAGE (image);
     gtk_widget_show (image);
     gtk_container_add (GTK_CONTAINER (self), image);
@@ -81,7 +61,10 @@ GtkWidget *
 multitab_close_button_new(const char *image_name)
 {
     MultitabCloseButton *self = (MultitabCloseButton *)
-            g_object_new (MULTITAB_TYPE_CLOSE_BUTTON, NULL);
+            g_object_new (MULTITAB_TYPE_CLOSE_BUTTON,
+                    "relief", GTK_RELIEF_NONE,
+                    "focus-on-click", FALSE,
+                    NULL);
 
     multitab_close_button_set_image (self, image_name);
     return GTK_WIDGET (self);
@@ -92,7 +75,7 @@ multitab_close_button_set_image(MultitabCloseButton *self,
         const char *image_name)
 {
     gtk_image_set_from_icon_name (self->image,
-            image_name ? image_name : "window-close",
+            image_name ? image_name : "window-close-symbolic",
             GTK_ICON_SIZE_MENU);
     multitab_close_button_set_size (self);
 }
