@@ -32,6 +32,7 @@
 #include "dynopts.h"
 #include "options.h"
 #include "profilegui.h"
+#include "resources.h"
 
 #define MANAGE_PREVIEW
 
@@ -43,7 +44,6 @@ struct _ProfileGUI {
     gboolean ignore_destroy;
     struct {
         guint word_chars : 1;
-        guint color_term : 1;
         guint term : 1;
         guint browser : 1;
         guint mailer : 1;
@@ -102,7 +102,6 @@ static void profilegui_update_from_entry(ProfileGUI * pg, const char *name)
 void profilegui_check_entries_for_changes(ProfileGUI * pg)
 {
     PG_UPDATE_IF(word_chars)
-    PG_UPDATE_IF(color_term)
     PG_UPDATE_IF(term)
     PG_UPDATE_IF(browser)
     PG_UPDATE_IF(mailer)
@@ -135,6 +134,13 @@ static void profilegui_set_close_buttons_shading(ProfileGUI *pg)
             GTK_TOGGLE_BUTTON(profilegui_widget(pg, "tab_close_btn"))));
 }
 
+static void profilegui_set_scrollbar_shading(ProfileGUI *pg)
+{
+    gtk_widget_set_sensitive(profilegui_widget(pg, "overlay_scrollbar"),
+            !gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(
+                    profilegui_widget(pg, "scrollbar_pos0"))));
+}
+
 static void profilegui_check_ssh_entries_for_changes(ProfileGUI * pg)
 {
     PG_UPDATE_IF(ssh_address)
@@ -151,7 +157,6 @@ void on_editable_changed(GtkEditable * editable, ProfileGUI *pg)
 #define PG_IF_CHANGED(s) if (!strcmp(n, #s)) PG_MEMBER(pg->changed, s) = 1
 
     PG_IF_CHANGED(word_chars);
-    else PG_IF_CHANGED(color_term);
     else PG_IF_CHANGED(term);
     else PG_IF_CHANGED(browser);
     else PG_IF_CHANGED(mailer);
@@ -230,7 +235,7 @@ void on_Profile_Editor_close(GtkWidget * widget, ProfileGUI * pg)
 void on_font_set(GtkFontButton * fontbutton, ProfileGUI * pg)
 {
     capplet_set_string(pg->capp.options,
-        "font", gtk_font_button_get_font_name(fontbutton));
+        "font", gtk_font_chooser_get_font(GTK_FONT_CHOOSER(fontbutton)));
 }
 
 void on_entry_activate(GtkEntry * entry, ProfileGUI * pg)
@@ -268,6 +273,18 @@ void on_cell_size_toggled(GtkToggleButton *button, ProfileGUI *pg)
     gtk_widget_set_sensitive(profilegui_widget(pg, "height"), state);
 }
 
+void on_scrollbar_pos_toggled(GtkRadioButton *button, ProfileGUI *pg)
+{
+    (void) button;
+    profilegui_set_scrollbar_shading(pg);
+}
+
+void on_kinetic_toggled(GtkToggleButton *button, ProfileGUI *pg)
+{
+    gboolean kinetic = gtk_toggle_button_get_active(button);
+    capplet_set_boolean_toggle(&pg->capp, "pixel_scrolling", kinetic);
+}
+
 #define DEFAULT_BACKSPACE_BINDING 0
 #define DEFAULT_DELETE_BINDING 0
 
@@ -288,9 +305,8 @@ void on_edit_colour_scheme_clicked(GtkButton *button, ProfileGUI *pg)
 {
     (void) button;
     GtkWidget *combo = capplet_lookup_widget(&pg->capp, "colour_scheme");
-    char *name;
-    name = gtk_combo_box_text_get_active_text(GTK_COMBO_BOX_TEXT(combo));
-    colourgui_open(name, gtk_widget_get_screen(combo));
+    char *name = gtk_combo_box_text_get_active_text(GTK_COMBO_BOX_TEXT(combo));
+    colourgui_open(name);
 }
 
 static void exit_action_changed(GtkComboBox *combo, ProfileGUI *pg)
@@ -390,10 +406,25 @@ static void profilegui_connect_handlers(ProfileGUI * pg)
     gtk_builder_connect_signals(pg->capp.builder, pg);
 }
 
+static gboolean profilegui_font_filter(const PangoFontFamily *family,
+        const PangoFontFace *face, gpointer data)
+{
+    (void) face;
+    (void) data;
+
+    return pango_font_family_is_monospace((PangoFontFamily *) family);
+}
+
 static void profilegui_fill_in_dialog(ProfileGUI * pg)
 {
     Options *profile = pg->capp.options;
     char *val;
+    GtkFontChooser *font_chooser;
+
+    capplet_set_spin_button(&pg->capp, "vspacing", 0);
+    capplet_set_spin_button(&pg->capp, "hspacing", 0);
+    capplet_set_toggle(&pg->capp, "bold_is_bright", FALSE);
+    capplet_set_radio(&pg->capp, "text_blink_mode", 0);
 
     if (options_lookup_int_with_default(profile, "full_screen", 0))
     {
@@ -407,15 +438,20 @@ static void profilegui_fill_in_dialog(ProfileGUI * pg)
     {
         capplet_set_toggle(&pg->capp, "cell_size", TRUE);
     }
-    gtk_font_button_set_font_name(
-            GTK_FONT_BUTTON(profilegui_widget(pg, "font_button")),
+    if (options_lookup_int_with_default(profile, "borderless", 0))
+    {
+        capplet_set_toggle(&pg->capp, "borderless", TRUE);
+    }
+    font_chooser = GTK_FONT_CHOOSER(profilegui_widget(pg, "font_button"));
+    gtk_font_chooser_set_filter_func(font_chooser, profilegui_font_filter,
+            NULL, NULL);
+    gtk_font_chooser_set_font( font_chooser,
             val = options_lookup_string_with_default(profile,
                 "font", "Monospace 10"));
     g_free(val);
     gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(profilegui_widget(pg,
                 "show_menubar")), !options_lookup_int_with_default(profile,
             "hide_menubar", FALSE));
-    capplet_set_boolean_toggle(&pg->capp, "allow_bold", TRUE);
     capplet_set_boolean_toggle(&pg->capp, "audible_bell", TRUE);
     capplet_set_boolean_toggle(&pg->capp, "bell_highlights_tab", TRUE);
     {
@@ -427,9 +463,7 @@ static void profilegui_fill_in_dialog(ProfileGUI * pg)
     }
     capplet_set_radio(&pg->capp, "cursor_shape", 0);
     capplet_set_boolean_toggle(&pg->capp, "hide_mouse", TRUE);
-    capplet_set_boolean_toggle(&pg->capp, "autowrap", TRUE);
-    capplet_set_text_entry(&pg->capp, "word_chars", "-,./?%&#_");
-    capplet_set_text_entry(&pg->capp, "color_term", NULL);
+    capplet_set_text_entry(&pg->capp, "word_chars", "-,./?%&#:_=+@~");
     capplet_set_text_entry(&pg->capp, "term", NULL);
     capplet_set_float_range(&pg->capp, "saturation", 1.0);
     capplet_set_combo(&pg->capp, "tab_pos", 0);
@@ -439,30 +473,24 @@ static void profilegui_fill_in_dialog(ProfileGUI * pg)
     capplet_set_boolean_toggle(&pg->capp, "always_show_tabs", TRUE);
     capplet_set_boolean_toggle(&pg->capp, "show_add_tab_btn", TRUE);
     capplet_set_boolean_toggle(&pg->capp, "new_tabs_adjacent", FALSE);
-    capplet_set_boolean_toggle(&pg->capp, "show_tab_num", TRUE);
     capplet_set_radio(&pg->capp, "middle_click_tab", 0);
     profilegui_set_close_buttons_shading(pg);
-    capplet_set_text_entry(&pg->capp, "browser", NULL);
-    capplet_set_radio(&pg->capp, "browser_spawn_type", 0);
-    capplet_set_text_entry(&pg->capp, "mailer", NULL);
-    capplet_set_radio(&pg->capp, "mailer_spawn_type", 0);
     capplet_set_text_entry(&pg->capp, "ssh", NULL);
-    capplet_set_radio(&pg->capp, "ssh_spawn_type", 2);
-    capplet_set_text_entry(&pg->capp, "filer", NULL);
-    capplet_set_radio(&pg->capp, "filer_spawn_type", 0);
-    capplet_set_text_entry(&pg->capp, "dir_filer", NULL);
-    capplet_set_radio(&pg->capp, "dir_spawn_type", 0);
-    capplet_set_boolean_toggle(&pg->capp, "file_as_dir", TRUE);
-    capplet_set_boolean_toggle(&pg->capp, "match_plain_files", FALSE);
+    /*capplet_set_boolean_toggle(&pg->capp, "match_plain_files", FALSE);*/
     capplet_set_spin_button(&pg->capp, "width", 80);
     capplet_set_spin_button(&pg->capp, "height", 24);
     on_cell_size_toggled(GTK_TOGGLE_BUTTON(profilegui_widget(pg, "cell_size")),
             pg);
+    capplet_set_boolean_toggle(&pg->capp, "overlay_scrollbar", TRUE);
     capplet_set_radio(&pg->capp, "scrollbar_pos", 1);
+    profilegui_set_scrollbar_shading(pg);
     capplet_set_boolean_toggle(&pg->capp, "limit_scrollback", FALSE);
     capplet_set_spin_button(&pg->capp, "scrollback_lines", 1000);
     capplet_set_boolean_toggle(&pg->capp, "scroll_on_output", FALSE);
     capplet_set_boolean_toggle(&pg->capp, "scroll_on_keystroke", FALSE);
+    gboolean kinetic = capplet_set_boolean_toggle(&pg->capp,
+            "kinetic_scrolling", TRUE);
+    capplet_set_boolean_toggle(&pg->capp, "pixel_scrolling", kinetic);
     capplet_set_combo(&pg->capp, "backspace_binding",
             DEFAULT_BACKSPACE_BINDING);
     capplet_set_combo(&pg->capp, "delete_binding",
@@ -481,13 +509,12 @@ static void profilegui_fill_in_dialog(ProfileGUI * pg)
     capplet_ignore_changes = FALSE;
     capplet_set_boolean_toggle(&pg->capp, "use_ssh", FALSE);
     capplet_set_boolean_toggle(&pg->capp, "login_shell", FALSE);
-    capplet_set_boolean_toggle(&pg->capp, "update_records", TRUE);
     capplet_set_boolean_toggle(&pg->capp, "use_custom_command", FALSE);
     capplet_set_text_entry(&pg->capp, "command", NULL);
     capplet_set_combo(&pg->capp, "exit_action", 0);
     profilegui_set_colour_scheme_combo(&pg->capp);
     capplet_set_spin_button_float(&pg->capp, "exit_pause");
-    capplet_set_text_entry(&pg->capp, "title_string", "%s");
+    capplet_set_text_entry(&pg->capp, "title_string", "%t. %s");
     capplet_set_text_entry(&pg->capp, "win_title", "%s");
     exit_action_changed(
         GTK_COMBO_BOX(capplet_lookup_widget(&pg->capp, "exit_action")),
@@ -515,8 +542,7 @@ static gboolean page_selected(GtkTreeSelection *selection,
 static void profilegui_setup_list_store(ProfileGUI *pg)
 {
     static char const *labels[] = {
-            N_("Appearance"), N_("General"), N_("Command"),
-            N_("Net URIs"), N_("File URIs"),
+            N_("Text"), N_("Appearance"), N_("Command"), N_("General"),
             N_("Scrolling"), N_("Keyboard"), N_("Tabs")
     };
     GtkTreeIter iter;
@@ -549,7 +575,7 @@ static void profilegui_setup_list_store(ProfileGUI *pg)
 }
 
 /* Loads a Profile and creates a working dialog box for it */
-ProfileGUI *profilegui_open(const char *profile_name, GdkScreen *scrn)
+ProfileGUI *profilegui_open(const char *profile_name)
 {
     static DynamicOptions *profiles = NULL;
     ProfileGUI *pg;
@@ -558,6 +584,7 @@ ProfileGUI *profilegui_open(const char *profile_name, GdkScreen *scrn)
             "width_adjustment", "height_adjustment",
             "exit_pause_adjustment", "scrollback_lines_adjustment",
             "saturation_adjustment", "ssh_port_adjustment",
+            "hspacing_adjustment", "vspacing_adjustment",
             NULL };
     static const char *obj_names[] = {
             "Profile_Editor", "ssh_dialog",
@@ -573,8 +600,6 @@ ProfileGUI *profilegui_open(const char *profile_name, GdkScreen *scrn)
     pg = g_hash_table_lookup(profilegui_being_edited, profile_name);
     if (pg)
     {
-        if (scrn)
-            gtk_window_set_screen(GTK_WINDOW(pg->dialog), scrn);
         gtk_window_present(GTK_WINDOW(pg->dialog));
         return pg;
     }
@@ -588,19 +613,16 @@ ProfileGUI *profilegui_open(const char *profile_name, GdkScreen *scrn)
         "roxterm profile");
 
     pg->capp.builder = gtk_builder_new();
-    if (!gtk_builder_add_objects_from_file(pg->capp.builder,
-            capplet_get_ui_filename(), (char **) adj_names, &error) ||
-            !gtk_builder_add_objects_from_file(pg->capp.builder,
-            capplet_get_ui_filename(), (char **) obj_names, &error))
+    if (!gtk_builder_add_objects_from_resource(pg->capp.builder,
+            ROXTERM_RESOURCE_UI, (char **) adj_names, &error) ||
+            !gtk_builder_add_objects_from_resource(pg->capp.builder,
+            ROXTERM_RESOURCE_UI, (char **) obj_names, &error))
     {
         g_error(_("Unable to load GTK UI definitions: %s"), error->message);
     }
     pg->dialog = profilegui_widget(pg, "Profile_Editor");
     pg->ssh_dialog = profilegui_widget(pg, "ssh_dialog");
 
-    if (scrn)
-        gtk_window_set_screen(GTK_WINDOW(pg->dialog), scrn);
-
     title = g_strdup_printf(_("ROXTerm Profile \"%s\""), profile_name);
     gtk_window_set_title(GTK_WINDOW(pg->dialog), title);
     g_free(title);
